@@ -1,7 +1,7 @@
 package Statocles::App;
 # ABSTRACT: Base class for Statocles applications
-$Statocles::App::VERSION = '0.027';
-use Statocles::Class;
+$Statocles::App::VERSION = '0.028';
+use Statocles::Base 'Class';
 
 1;
 
@@ -15,7 +15,7 @@ Statocles::App - Base class for Statocles applications
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
